Changelog
=========

0.2.0 (2026-01-26)
------------------

General
.......
- Added Tool Menu for Check PEtab and Simulate actions (#222)
- Added SBML export functionality (#220)
- Added delete from header feature for table models (#216)
- Added option to hide SBML view for sole Antimony view (#210)
- Added offboarding information window after saving model (#209)
- Fixed multi-file upload to support multiple measurement and other files (#207)

Documentation
.............
- Added next steps guide with code examples (#219)
- Added Boehm example and simple conversion example (#218)
- Added tutorial walkthrough with pictures and extended feature documentation (#217)

0.1.5 (2025-11-25)
------------------

Initial release with core PEtab GUI functionality.
